==> FIESTA_3.6.4.tar.gz: FIESTA/tests/testthat/_snaps/modGBratio.md <==
# modGBratio Testing

    Code
      modGBratio_VOL_est
    Output
                                      Forest type Estimate Percent Sampling Error
      1                    Rocky Mountain juniper      164                  38.73
      2                          Juniper woodland     22.3                  82.79
      3                 Pinyon / juniper woodland       --                     --
      4                               Douglas-fir   1451.9                   13.7
      5                            Ponderosa pine   1275.4                  10.25
      6                          Engelmann spruce   2822.8                  17.11
      7          Engelmann spruce / subalpine fir   2101.4                    7.1
      8                             Subalpine fir   1624.4                   9.58
      9                               Blue spruce   2861.1                      0
      10                           Lodgepole pine   1569.8                   7.27
      11                              Limber pine    221.8                  40.96
      12                           Whitebark pine    667.9                  17.45
      13                                  Bur oak    345.3                  44.36
      14                 Elm / ash / black locust    133.7                      0
      15                               Cottonwood   1926.8                   34.5
      16 Sugarberry / hackberry / elm / green ash    420.6                      0
      17                                    Aspen    681.5                  22.93
      18                               Nonstocked     64.2                   39.8
      19                                    Total   1292.7                   4.46

---

    Code
      modGBratio_TPA_est
    Output
                                      Forest type Estimate Percent Sampling Error
      1                    Rocky Mountain juniper    149.9                  17.49
      2                          Juniper woodland    159.1                   14.1
      3                 Pinyon / juniper woodland     72.2                      0
      4                               Douglas-fir    272.9                  15.15
      5                            Ponderosa pine    293.2                  11.01
      6                          Engelmann spruce      432                  15.51
      7          Engelmann spruce / subalpine fir      596                   7.68
      8                             Subalpine fir    542.7                  10.84
      9                               Blue spruce    321.2                      0
      10                           Lodgepole pine    629.3                   8.63
      11                              Limber pine    105.1                  34.52
      12                           Whitebark pine    372.7                  17.08
      13                                  Bur oak    347.8                   48.5
      14                 Elm / ash / black locust        6                      0
      15                               Cottonwood    110.4                  24.74
      16 Sugarberry / hackberry / elm / green ash     96.3                      0
      17                                    Aspen    415.1                  11.08
      18                               Nonstocked     17.5                  29.96
      19                                    Total    413.1                   4.55

---

    Code
      modGBratio_BA_est
    Output
                                      Forest type Estimate Percent Sampling Error
      1                    Rocky Mountain juniper     49.2                  11.82
      2                          Juniper woodland    131.1                  14.38
      3                 Pinyon / juniper woodland     93.7                      0
      4                               Douglas-fir     79.4                   9.35
      5                            Ponderosa pine     79.1                   6.98
      6                          Engelmann spruce    125.7                  11.66
      7          Engelmann spruce / subalpine fir    107.9                    5.2
      8                             Subalpine fir     90.6                   8.01
      9                               Blue spruce    111.9                      0
      10                           Lodgepole pine       90                   5.44
      11                              Limber pine     22.4                   29.8
      12                           Whitebark pine     61.6                  15.41
      13                                  Bur oak     43.2                  28.71
      14                 Elm / ash / black locust        7                      0
      15                               Cottonwood    103.3                   27.4
      16 Sugarberry / hackberry / elm / green ash     39.8                      0
      17                                    Aspen     52.1                  15.01
      18                               Nonstocked      4.7                   25.4
      19                                    Total     79.3                   3.13

==> FIESTA_3.7.0.tar.gz: FIESTA/tests/testthat/_snaps/modGBratio.md <==
# modGBratio Testing

    Code
      modGBratio_VOL_est
    Output
                                      Forest type Estimate Percent Sampling Error
      1                    Rocky Mountain juniper      164                  38.73
      2                          Juniper woodland     22.3                  82.79
      3                 Pinyon / juniper woodland       --                     --
      4                               Douglas-fir   1451.9                   13.7
      5                            Ponderosa pine   1275.4                  10.25
      6                          Engelmann spruce   2822.8                  17.11
      7          Engelmann spruce / subalpine fir   2101.4                    7.1
      8                             Subalpine fir   1624.4                   9.58
      9                               Blue spruce   2861.1                      0
      10                           Lodgepole pine   1569.8                   7.27
      11                              Limber pine    221.8                  40.96
      12                           Whitebark pine    667.9                  17.45
      13                                  Bur oak    345.3                  44.36
      14                 Elm / ash / black locust    133.7                      0
      15                               Cottonwood   1926.8                   34.5
      16 Sugarberry / hackberry / elm / green ash    420.6                      0
      17                                    Aspen    681.5                  22.93
      18                               Nonstocked     64.2                   39.8
      19                                    Other       --                     --
      20                                    Total   1292.7                   4.46

---

    Code
      modGBratio_TPA_est
    Output
                                      Forest type Estimate Percent Sampling Error
      1                    Rocky Mountain juniper    149.9                  17.49
      2                          Juniper woodland    159.1                   14.1
      3                 Pinyon / juniper woodland     72.2                      0
      4                               Douglas-fir    272.9                  15.15
      5                            Ponderosa pine    293.2                  11.01
      6                          Engelmann spruce      432                  15.51
      7          Engelmann spruce / subalpine fir      596                   7.68
      8                             Subalpine fir    542.7                  10.84
      9                               Blue spruce    321.2                      0
      10                           Lodgepole pine    629.3                   8.63
      11                              Limber pine    105.1                  34.52
      12                           Whitebark pine    372.7                  17.08
      13                                  Bur oak    347.8                   48.5
      14                 Elm / ash / black locust        6                      0
      15                               Cottonwood    110.4                  24.74
      16 Sugarberry / hackberry / elm / green ash     96.3                      0
      17                                    Aspen    415.1                  11.08
      18                               Nonstocked     17.5                  29.96
      19                                    Other       --                     --
      20                                    Total    413.1                   4.55
